---
name: Bug report
about: Create a report describing unexpected or incorrect behavior in `utilipy`.
title: '[BUG] '
labels: Bug
assignees: 'nstarman'

---

### Description
<!-- Provide a general description of the bug. -->

### Expected behavior
<!-- What did you expect to happen. -->

### Actual behavior
<!-- What actually happened. -->
<!-- Was the output confusing or poorly described? -->

### Steps to Reproduce
<!-- Ideally a code example could be provided so we can run it ourselves. -->
<!-- If you are pasting code, use triple backticks (```) around
your code snippet. -->
<!-- If necessary, sanitize your screen output to be pasted so you do not
reveal secrets like tokens and passwords. -->

1.  [First Step]
2.  [Second Step]
3.  [and so on...]

```python
# Put your Python code snippet here.
```

### System Details
<!-- Even if you do not think this is necessary, it is useful information for the maintainers.
Please run the following snippet and paste the output below:
import platform; print(platform.platform())
import sys; print("Python", sys.version)
import astropy; print("astropy", astropy.__version__)
import astroquery; print("astroquery", astroquery.__version__)
import matplotlib; print("Matplotlib", matplotlib.__version__)
import numpy; print("Numpy", numpy.__version__)
import scipy; print("Scipy", scipy.__version__)
-->

### Checklist

- [ ] Check out our [contributing guidelines](https://github.com/astropy/astropy/blob/master/CONTRIBUTING.md).
- [ ] Check out our [code of conduct](https://github.com/astropy/astropy/blob/master/CODE_OF_CONDUCT.md).
- [ ] Search the GitHub repository to see if a similar issue has already been posted. If a similar issue is closed, have a quick look to see if you are satisfied by the resolution. If not please go ahead and open an issue!
- [ ] Please check that the development version still produces the same bug. You can install development version with ``pip install git+https://github.com/astropy/astropy`` command.
